@@ -157,7 +157,7 @@ get_default_path (void)
 {
 	gchar *old_directory;
 	gchar *new_directory;
-	gchar *alias_directory = NULL;
+	g_autofree gchar *alias_directory = NULL;
 
 #if WITH_DEBUG
 	const gchar *path = g_getenv ("GNOME_KEYRING_TEST_PATH");
@@ -608,6 +608,7 @@ service_method_lock (GkdExportedService *skeleton,
 	locked = (gchar **) g_ptr_array_free (array, FALSE);
 	gkd_exported_service_complete_lock (skeleton, invocation,
 					    (const gchar **) locked, "/");
+	g_free (locked);
 
 	return TRUE;
 }
