@@ -959,6 +959,11 @@ sec_block_create (size_t size,
 		return NULL;
 	}
 
+	/* Whatever size we were asked for, we'll need a little more space:
+	 * each allocation has an overhead of 2 words, for the guard
+	 * pointers before and after. */
+	size += (2 * sizeof (word_t));
+
 	/* The size above is a minimum, we're free to go bigger */
 	if (size < DEFAULT_BLOCK_SIZE)
 		size = DEFAULT_BLOCK_SIZE;
@@ -1060,8 +1065,14 @@ egg_secure_alloc_full (const char *tag,
 		/* None of the current blocks have space, allocate new */
 		if (!memory) {
 			block = sec_block_create (length, tag);
-			if (block)
+			if (block) {
 				memory = sec_alloc (block, tag, length);
+
+				if (!memory && egg_secure_warnings)
+					fprintf (stderr,
+						 "internal error: memory block sized to hold %lu bytes was too small\n",
+						 (unsigned long) length);
+			}
 		}
 
 #ifdef WITH_VALGRIND
