@@ -74,7 +74,7 @@ G_DEFINE_TYPE_EXTENDED (GkmCertificate, gkm_certificate, GKM_TYPE_OBJECT, 0,
 static void
 init_quarks (void)
 {
-	static volatile gsize quarks_inited = 0;
+	static gsize quarks_inited = 0;
 
 	if (g_once_init_enter (&quarks_inited)) {
 		#define QUARK(name, value) \
