@@ -403,62 +403,6 @@ auto_unlock_remove_token (CK_TOKEN_INFO_PTR info)
  * PROMPTING
  */
 
-static CK_ATTRIBUTE_PTR
-get_unlock_options_from_object (GkmWrapPrompt *self, CK_ULONG_PTR n_options)
-{
-	CK_ATTRIBUTE_PTR options;
-	CK_ATTRIBUTE attr;
-	CK_ULONG i;
-	CK_RV rv;
-
-	g_assert (GKM_IS_WRAP_PROMPT (self));
-	g_assert (self->module);
-	g_assert (n_options);
-
-	*n_options = 0;
-
-	attr.type = CKA_G_CREDENTIAL_TEMPLATE;
-	attr.ulValueLen = 0;
-	attr.pValue = NULL;
-
-	/* Get the length of the entire template */
-	rv = (self->module->C_GetAttributeValue) (self->session, self->object, &attr, 1);
-	if (rv != CKR_OK) {
-		if (rv != CKR_ATTRIBUTE_TYPE_INVALID)
-			g_warning ("couldn't get credential template for prompt: %s",
-			           gkm_log_rv (rv));
-		return NULL;
-	}
-
-	/* Number of attributes, rounded down */
-	*n_options = (attr.ulValueLen / sizeof (CK_ATTRIBUTE));;
-	attr.pValue = options = pool_alloc (self, attr.ulValueLen);
-
-	/* Get the size of each value */
-	rv = (self->module->C_GetAttributeValue) (self->session, self->object, &attr, 1);
-	if (rv != CKR_OK) {
-		g_warning ("couldn't read credential template for prompt: %s",
-		           gkm_log_rv (rv));
-		return NULL;
-	}
-
-	/* Allocate memory for each value */
-	for (i = 0; i < *n_options; ++i) {
-		if (options[i].ulValueLen != (CK_ULONG)-1)
-			options[i].pValue = pool_alloc (self, options[i].ulValueLen);
-	}
-
-	/* Now get the actual values */
-	rv = (self->module->C_GetAttributeValue) (self->session, self->object, &attr, 1);
-	if (rv != CKR_OK) {
-		g_warning ("couldn't retrieve credential template for prompt: %s",
-		           gkm_log_rv (rv));
-		return NULL;
-	}
-
-	return options;
-}
-
 static void
 set_unlock_options_on_object (GkmWrapPrompt *self, CK_ATTRIBUTE_PTR options, CK_ULONG n_options)
 {
@@ -509,16 +453,11 @@ get_unlock_options_from_prompt (GkmWrapPrompt *self, CK_ULONG_PTR n_options)
 }
 
 static void
-set_unlock_options_on_prompt (GkmWrapPrompt *self, CK_ATTRIBUTE_PTR options, CK_ULONG n_options)
+set_unlock_options_on_prompt (GkmWrapPrompt *self)
 {
 	gboolean chosen = FALSE;
-	gboolean bval;
 
 	g_assert (GKM_IS_WRAP_PROMPT (self));
-	g_assert (options || !n_options);
-
-	if (gkm_attributes_find_boolean (options, n_options, CKA_GNOME_TRANSIENT, &bval))
-		chosen = bval;
 
 	gcr_prompt_set_choice_chosen (GCR_PROMPT (self), chosen);
 }
@@ -588,9 +527,7 @@ setup_unlock_keyring_login (GkmWrapPrompt *self)
 	prompt = GCR_PROMPT (self);
 
 	gcr_prompt_set_title (prompt, _("Unlock Login Keyring"));
-
-	text = _("Enter password to unlock your login keyring");
-	gcr_prompt_set_message (prompt, text);
+	gcr_prompt_set_message (prompt, _("Authentication required"));
 
 	if (gkm_wrap_login_did_unlock_fail ())
 		text = _("The password you use to log in to your computer no longer matches that of your login keyring.");
@@ -614,9 +551,7 @@ setup_unlock_keyring_other (GkmWrapPrompt *self,
 	prompt = GCR_PROMPT (self);
 
 	gcr_prompt_set_title (prompt, _("Unlock Keyring"));
-
-	text = _("Enter password to unlock");
-	gcr_prompt_set_message (prompt, text);
+	gcr_prompt_set_message (prompt, _("Authentication required"));
 
 	text = g_markup_printf_escaped (_("An application wants access to the keyring “%s”, but it is locked"), label);
 	gcr_prompt_set_description (prompt, text);
@@ -645,21 +580,6 @@ calc_unlock_object_title (CK_OBJECT_CLASS klass)
 	}
 }
 
-static const gchar*
-calc_unlock_object_primary (CK_OBJECT_CLASS klass)
-{
-	switch (klass) {
-	case CKO_PRIVATE_KEY:
-		return _("Enter password to unlock the private key");
-	case CKO_CERTIFICATE:
-		return _("Enter password to unlock the certificate");
-	case CKO_PUBLIC_KEY:
-		return _("Enter password to unlock the public key");
-	default:
-		return _("Enter password to unlock");
-	}
-}
-
 static const gchar *
 calc_unlock_object_choice (CK_OBJECT_CLASS klass)
 {
@@ -707,7 +627,7 @@ setup_unlock_object (GkmWrapPrompt *self,
 	prompt = GCR_PROMPT (self);
 
 	gcr_prompt_set_title (prompt, calc_unlock_object_title (klass));
-	gcr_prompt_set_message (prompt, calc_unlock_object_primary (klass));
+	gcr_prompt_set_message (prompt, _("Authentication required"));
 
 	text = calc_unlock_object_secondary (klass, label);
 	gcr_prompt_set_description (prompt, text);
@@ -783,7 +703,7 @@ setup_unlock_token (GkmWrapPrompt *self,
 
 	/* Build up the prompt */
 	gcr_prompt_set_title (prompt, _("Unlock certificate/key storage"));
-	gcr_prompt_set_message (prompt, _("Enter password to unlock the certificate/key storage"));
+	gcr_prompt_set_message (prompt, _("Authentication required"));
 
 	/* TRANSLATORS: The storage is locked, and needs unlocking before the application can use it. */
 	text = g_strdup_printf (_("An application wants access to the certificate/key storage “%s”, but it is locked"), label);
@@ -1049,11 +969,8 @@ gkm_wrap_prompt_do_credential (GkmWrapPrompt *self, CK_ATTRIBUTE_PTR *template,
 		setup_unlock_prompt (self, attrs, n_attrs, self->iteration == 1);
 
 		/* Now load up the unlock options into the prompt*/
-		if (self->iteration == 1) {
-			options = get_unlock_options_from_object (self, &n_options);
-			if (options != NULL)
-				set_unlock_options_on_prompt (self, options, n_options);
-		}
+		if (self->iteration == 1)
+			set_unlock_options_on_prompt (self);
 
 		++(self->iteration);
 
@@ -1148,7 +1065,7 @@ setup_init_token (GkmWrapPrompt *self,
 	/* Build up the prompt */
 	gcr_prompt_set_password_new (prompt, TRUE);
 	gcr_prompt_set_title (prompt, _("New Password Required"));
-	gcr_prompt_set_message (prompt, _("New password required for secure storage"));
+	gcr_prompt_set_message (prompt, _("New password required"));
 
 	text = g_strdup_printf (_("In order to prepare “%s” for storage of certificates or keys, a password is required"), label);
 	gcr_prompt_set_description (prompt, text);
@@ -1266,7 +1183,7 @@ setup_set_token_original (GkmWrapPrompt *self,
 	/* Build up the prompt */
 	gcr_prompt_set_password_new (prompt, FALSE);
 	gcr_prompt_set_title (prompt, _("Change Password"));
-	gcr_prompt_set_message (prompt, _("Original password for secure storage"));
+	gcr_prompt_set_message (prompt, _("Authentication required"));
 
 	text = g_strdup_printf (_("To change the password for “%s”, the original password is required"), label);
 	gcr_prompt_set_description (prompt, text);
@@ -1297,7 +1214,7 @@ setup_set_token_password (GkmWrapPrompt *self,
 	/* Build up the prompt */
 	gcr_prompt_set_password_new (prompt, TRUE);
 	gcr_prompt_set_title (prompt, _("Change Password"));
-	gcr_prompt_set_message (prompt, _("Change password for secure storage"));
+	gcr_prompt_set_message (prompt, _("Change password"));
 
 	text = g_strdup_printf (_("Type a new password for “%s”"), label);
 	gcr_prompt_set_description (prompt, text);
